@@ -14,6 +14,8 @@ typedef Eo Efl_Screen;
 
 #endif
 /** Efl screen interface
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Screen
  */
@@ -22,44 +24,63 @@ typedef Eo Efl_Screen;
 EWAPI const Efl_Class *efl_screen_interface_get(void);
 
 /**
- * @brief Get screen geometry details for the screen that a window is on.
+ * @brief Screen size (in pixels) for the screen.
  *
- * Note that on some display systems this information is not available (this
- * could be the case Wayland for instance).
+ * Note that on some display systems this information is not available and a
+ * value of 0x0 will be returned.
  *
  * @param[in] obj The object.
  *
- * @return The screen size.
+ * @return The screen size in pixels.
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Screen
  */
-EOAPI Eina_Size2D efl_screen_size_get(const Eo *obj);
+EOAPI Eina_Size2D efl_screen_size_in_pixels_get(const Eo *obj);
 
 /**
- * @brief Get the rotation of the screen.
+ * @brief Screen scaling factor.
+ *
+ * This is the factor by which window contents will be scaled on the screen.
+ *
+ * Note that on some display systems this information is not available and a
+ * value of 1.0 will be returned.
+ *
+ * @param[in] obj The object.
+ *
+ * @return The screen scaling factor.
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Screen
+ */
+EOAPI float efl_screen_scale_factor_get(const Eo *obj);
+
+/**
+ * @brief The rotation of the screen.
  *
  * Most engines only return multiples of 90.
  *
  * @param[in] obj The object.
  *
- * @return The degree of the screen.
+ * @return Screen rotation in degrees.
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Screen
  */
 EOAPI int efl_screen_rotation_get(const Eo *obj);
 
 /**
- * @brief Get screen dpi for the screen that a window is on.
+ * @brief The pixel density in DPI (Dots Per Inch) for the screen that a window
+ * is on.
  *
  * @param[in] obj The object.
- * @param[out] xdpi Pointer to value to store return horizontal dpi. May be
- * @c null.
- * @param[out] ydpi Pointer to value to store return vertical dpi. May be
- * @c null.
+ * @param[out] xdpi Horizontal DPI.
+ * @param[out] ydpi Vertical DPI.
  *
- * @since 1.7
+ * @since 1.22
  *
  * @ingroup Efl_Screen
  */
