@@ -98,7 +98,7 @@ EOAPI const char *efl_config_profile_get(const Eo *obj);
  *
  * @ingroup Efl_Config_Global
  */
-EOAPI Eina_Iterator *efl_config_profile_iterate(Eo *obj, Eina_Bool hidden);
+EOAPI Eina_Iterator *efl_config_profile_iterate(Eo *obj, Eina_Bool hidden) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Returns whether a profile exists or not.
@@ -124,7 +124,7 @@ EOAPI Eina_Bool efl_config_profile_exists(Eo *obj, const char *profile);
  *
  * @ingroup Efl_Config_Global
  */
-EOAPI Eina_Stringshare *efl_config_profile_dir_get(Eo *obj, const char *profile, Eina_Bool is_user);
+EOAPI Eina_Stringshare *efl_config_profile_dir_get(Eo *obj, const char *profile, Eina_Bool is_user) EFL_TRANSFER_OWNERSHIP;
 
 #ifdef EFL_CONFIG_GLOBAL_PROTECTED
 /**
