@@ -13,7 +13,6 @@ typedef Eo Efl_Ui_Widget_Part;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief This is the base class for all "Part" handles in Efl.Ui widgets.
  *
@@ -21,11 +20,12 @@ typedef Eo Efl_Ui_Widget_Part;
  * is limited to exactly one function call only. Each widget class should
  * expose more specific types for their API-defined parts.
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Ui_Widget_Part
  */
 #define EFL_UI_WIDGET_PART_CLASS efl_ui_widget_part_class_get()
 
 EWAPI const Efl_Class *efl_ui_widget_part_class_get(void);
-#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
